@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2017 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -52,6 +52,7 @@ About.prototype.beginEvent = function() {
          + "</head>";
 
     this.applicationName = qApp.applicationName;
+    this.version = undefined;
     this.iconFile = undefined;
 
     // init plugin view:
@@ -88,19 +89,29 @@ About.prototype.beginEvent = function() {
 };
 
 About.prototype.initAboutApp = function(textBrowser) {
+    var version = RSettings.getVersionString();
+    var versionComplete = "%1.%2.%3.%4"
+        .arg(RSettings.getMajorVersion())
+        .arg(RSettings.getMinorVersion())
+        .arg(RSettings.getRevisionVersion())
+        .arg(RSettings.getBuildVersion());
+
+    if (!isNull(this.version)) {
+        version = "";
+        versionComplete = this.version;
+    }
+
     var html =
             "<html>"
             + this.head
             + "<body>"
             + "<h1>%1</h1>".arg(this.applicationName)
-            + "<hr/>"
-            + "<table border='0'><tr>"
-            + "<td><b>" + qsTr("Version:") + "</b> </td><td>%1.%2.%3.%4 (%5)</td>"
-              .arg(RSettings.getMajorVersion())
-              .arg(RSettings.getMinorVersion())
-              .arg(RSettings.getRevisionVersion())
-              .arg(RSettings.getBuildVersion())
-              .arg(RSettings.getVersionString())
+            + "<hr/>";
+            html +=
+              "<table border='0'><tr>"
+            + "<td><b>" + qsTr("Version:") + "</b> </td><td>%1 %2</td>"
+              .arg(versionComplete)
+              .arg(version.length>0 ? "("+version+")" : "")
             + "</tr><tr>"
             + "<td><b>" + qsTr("Internet:") + "</b> </td><td><a href='http://%1'>%1</a></td>".arg(qApp.organizationDomain)
             + "</tr><tr>"
@@ -109,14 +120,19 @@ About.prototype.initAboutApp = function(textBrowser) {
             + "<td><b>" + qsTr("Revision:") + "</b> </td><td>%1</td>".arg(RSettings.getRevisionString().left(7))
             + "</tr><tr>"
             + "<td><b>" + qsTr("Qt Version:") + "</b> </td><td>%1</td>".arg(RSettings.getQtVersionString())
-            + "</tr><tr>";
-            if (RS.getBuildCpuArchitecture().length!==0) {
-                html += "<td><b>" + qsTr("Architecture:") + "</b> </td><td>%1</td>".arg(RS.getBuildCpuArchitecture())
-                + "</tr><tr>";
+            + "</tr>";
+            var bca = RS.getBuildCpuArchitecture();
+            if (bca.length!==0) {
+                html += "<tr><td><b>" + qsTr("Architecture:") + "</b> </td><td>%1</td>".arg(bca) + "</tr>";
             }
-            html += "<td><b>" + qsTr("Compiler:") + "</b> </td><td>%1</td>".arg(RSettings.getCompilerVersion())
-            + "</tr></table>"
-            + "<hr/>"
+            html += "<tr><td><b>" + qsTr("Compiler:") + "</b> </td><td>%1</td>".arg(RSettings.getCompilerVersion()) + "</tr>";
+            var lk = RSettings.getStringValue("License/LicenseKey", "");
+            if (lk.length>0) {
+                html += "<tr><td><b>" + qsTr("License Key:") + "</b> </td><td>%1</td>".arg(lk) + "</tr>";
+            }
+            html += "</table>";
+
+            html += "<hr/>"
             + "<p>" + qsTr("%1 is an application for computer-aided design (CAD).").arg(this.applicationName) + "</p>"
             + "<p/>";
 
@@ -132,8 +148,8 @@ About.prototype.initAboutApp = function(textBrowser) {
             + "<p/>"
             + "<p>" + qsTr("All brand or product names are trademarks or registered trademarks of their respective holders.") + "</p>"
             + "<p/>"
-            + "<p>© 2011-2018 RibbonSoft GmbH.</p>"
-            + "<p>" + qsTr("Portions of this software © 2008-2017 The Qt Company Ltd.") + "</p>"
+            + "<p>© 2011-2018 RibbonSoft, GmbH.</p>"
+            + "<p>" + qsTr("Portions of this software © %1 The Qt Company Ltd.").arg("2008-2018") + "</p>"
             + "<p>" + qsTr("The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.") + "</p>"
             + "<p/>"
             + "</body></html>";
@@ -155,9 +171,7 @@ About.prototype.initAboutPlugins = function(textBrowser) {
         html += qsTr("No plugins found.");
     }
     else {
-        var namePostfixesSlash = [];
-        var namePostfixesSpace = [];
-        var nameOverrides = [];
+        var maxPri = undefined;
         for (var i=0; i<numPlugins; i++) {
             html += "<table border='0' width='100%'>";
 
@@ -165,28 +179,41 @@ About.prototype.initAboutPlugins = function(textBrowser) {
 
             var pluginInfo = RPluginLoader.getPluginInfo(i);
 
+            // override priority:
+            var pri = pluginInfo.get("OverridePriority");
+            if (!isNull(pri)) {
+                pri = parseInt(pri);
+            }
+            else {
+                // default to lowest priority:
+                pri = 0;
+            }
+
+            //qDebug("ID:", pluginInfo.get("ID"));
+            //qDebug("pri:", pri);
+
             // plugin about info:
             text = pluginInfo.get("Name", qsTr("No information available"));
             html += this.getTableRow(qsTr("Plugin:"), "<b>" + Qt.escape(text) + "</b>", false);
 
-            text = pluginInfo.get("NamePostfix");
-            if (!isNull(text)) {
-                if (text.startsWith("/")) {
-                    namePostfixesSlash.push(text);
-                }
-                else {
-                    namePostfixesSpace.push(text);
-                }
-            }
+            // overrides:
+            if (isNull(maxPri) || pri>maxPri) {
+                maxPri = pri;
 
-            text = pluginInfo.get("NameOverride");
-            if (!isNull(text)) {
-                nameOverrides.push(text);
-            }
+                text = pluginInfo.get("NameOverride");
+                if (!isNull(text)) {
+                    this.applicationName = text;
+                }
 
-            text = pluginInfo.get("IconOverride");
-            if (!isNull(text)) {
-                this.iconFile = text;
+                text = pluginInfo.get("VersionOverride");
+                if (!isNull(text)) {
+                    this.version = text;
+                }
+
+                text = pluginInfo.get("IconOverride");
+                if (!isNull(text)) {
+                    this.iconFile = text;
+                }
             }
 
             // ID:
@@ -231,12 +258,7 @@ About.prototype.initAboutPlugins = function(textBrowser) {
                         var fixedUrl = url.toString();
                         fixedUrl = fixedUrl.replace("QUrl( \"", "");
                         fixedUrl = fixedUrl.replace("\" )", "");
-                        html += this.getTableRow(
-                            qsTr("Internet:"),
-                            "<a href='%2'>%3</a>"
-                                .arg(fixedUrl).arg(fixedUrl),
-                            false
-                        );
+                        html += this.getTableRow(qsTr("Internet:"), "<a href='%2'>%3</a>" .arg(fixedUrl).arg(fixedUrl), false);
                     }
                 }
             }
@@ -273,21 +295,6 @@ About.prototype.initAboutPlugins = function(textBrowser) {
             html += "</table>";
             html += "<hr/>";
         }
-
-        // name override:
-        if (nameOverrides.length!==0) {
-            var a = nameOverrides.sort( function (a, b) { return b.length - a.length; });
-            this.applicationName = a[0];
-        }
-        else {
-            // add name postfixes:
-
-            // e.g. "/XYZ" for "MyApp/XYZ":
-            namePostfixesSlash.sort();
-            // e.g. "Incredible Edition" for "MyApp Incredible Edition":
-            namePostfixesSpace.sort();
-            this.applicationName = qApp.applicationName + namePostfixesSlash.join("") + namePostfixesSpace.join("");
-        }
     }
 
     if (this.applicationName==="QCAD") {
@@ -408,12 +415,23 @@ About.prototype.initAboutSystem = function(textEdit) {
     var i;
 
     text += "Versions";
-    text += "\n%1 version: %2.%3.%4.%5"
-        .arg(qApp.applicationName)
-        .arg(RSettings.getMajorVersion())
-        .arg(RSettings.getMinorVersion())
-        .arg(RSettings.getRevisionVersion())
-        .arg(RSettings.getBuildVersion());
+    if (!isNull(this.version)) {
+        text += "\n%1 version: %2"
+            .arg(qApp.applicationName)
+            .arg(this.version);
+    }
+    else {
+        text += "\n%1 version: %2.%3.%4.%5"
+            .arg(qApp.applicationName)
+            .arg(RSettings.getMajorVersion())
+            .arg(RSettings.getMinorVersion())
+            .arg(RSettings.getRevisionVersion())
+            .arg(RSettings.getBuildVersion());
+    }
+    var lk = RSettings.getStringValue("License/LicenseKey", "");
+    if (lk.length>0) {
+        text += "\nLicense Key: " + lk;
+    }
     text += "\nDate: " + RSettings.getReleaseDate();
     text += "\nQt version: " + RSettings.getQtVersionString();
     text += "\nCompiler version: " + RSettings.getCompilerVersion();
