@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2017 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -23,6 +23,8 @@ include("map.js");
 function WidgetFactory() {
 }
 
+WidgetFactory.includeBasePath = includeBasePath;
+
 /**
  * Creates a dialog with the given \c parent, based on the UI file 
  * named \c uiFile in \c basePath. The dialog has a header area in
@@ -72,7 +74,9 @@ WidgetFactory.createWidget = function(basePath, uiFile, parent) {
 
     var fileInfo = new QFileInfo(uiFile);
     if (!fileInfo.exists() && !fileInfo.isAbsolute()) {
-        uiFile = basePath + "/" + uiFile;
+        if (basePath.length>0) {
+            uiFile = basePath + "/" + uiFile;
+        }
 
         fileInfo = new QFileInfo(uiFile);
         if (!fileInfo.exists()) {
@@ -995,7 +999,7 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
 
         // automatically set tool tip and icon for reset button:
         if (w.objectName==="Reset") {
-            w.icon = new QIcon("scripts/ResetToDefaults.svg");
+            w.icon = new QIcon(WidgetFactory.includeBasePath + "/ResetToDefaults.svg");
             w.toolTip = qsTr("Restore defaults");
         }
     }
@@ -1199,6 +1203,27 @@ WidgetFactory.initVAlignCombo = function(comboBox) {
     comboBox.addItem(qsTr("Bottom"), RS.VAlignBottom);
 };
 
+WidgetFactory.initOrientationCombo = function(comboBox) {
+    comboBox.clear();
+
+    if (RSettings.isQt(5)) {
+        comboBox.addItem("↻ " + qsTr("Clockwise"), RS.CW);
+        comboBox.addItem("↺ " + qsTr("Counterclockwise"), RS.CCW);
+    }
+    else {
+        comboBox.addItem(qsTr("Clockwise"), RS.CW);
+        comboBox.addItem(qsTr("Counterclockwise"), RS.CCW);
+    }
+};
+
+WidgetFactory.initArcSymbolTypeCombo = function(comboBox) {
+    comboBox.clear();
+
+    comboBox.addItem(qsTr("Preceding"), 0);
+    comboBox.addItem(qsTr("Above"), 1);
+    comboBox.addItem(qsTr("None"), 2);
+};
+
 WidgetFactory.installComboBoxEventFilter = function(widget) {
     if (isNull(widget)) {
         return;
